@@ -6,6 +6,14 @@ from typing import Optional
 
 from connexion import App
 
+from foca.security.access_control.register_access_control import (
+    register_access_control
+)
+from foca.security.access_control.constants import (
+    DEFAULT_SPEC_CONTROLLER,
+    DEFAULT_ACCESS_CONTROL_DB_NAME,
+    DEFAULT_ACESS_CONTROL_COLLECTION_NAME,
+)
 from foca.api.register_openapi import register_openapi
 from foca.config.config_parser import ConfigParser
 from foca.database.register_mongodb import register_mongodb
@@ -117,6 +125,41 @@ class Foca:
         else:
             logger.info("No database support configured.")
 
+        # Register permission management and casbin enforcer
+        if conf.security.auth.required:
+            if (
+                conf.security.access_control.api_specs is None or
+                conf.security.access_control.api_controllers is None
+            ):
+                conf.security.access_control.api_controllers = (
+                    DEFAULT_SPEC_CONTROLLER
+                )
+
+            if conf.security.access_control.db_name is None:
+                conf.security.access_control.db_name = (
+                    DEFAULT_ACCESS_CONTROL_DB_NAME
+                )
+
+            if conf.security.access_control.collection_name is None:
+                conf.security.access_control.collection_name = (
+                    DEFAULT_ACESS_CONTROL_COLLECTION_NAME
+                )
+
+            cnx_app = register_access_control(
+                cnx_app=cnx_app,
+                mongo_config=conf.db,
+                access_control_config=conf.security.access_control
+            )
+        else:
+            if (
+                conf.security.access_control.api_specs or
+                conf.security.access_control.api_controllers
+            ):
+                logger.error(
+                    "Please enable security config to register "
+                    "access control."
+                )
+
         # Create Celery app
         if conf.jobs:
             create_celery_app(cnx_app.app)
